<?php
/**
 * Functions used in Dukapress
 *
 */



 if (!function_exists('dukapress_category_list')) :

	/**
	 * Retrieve product's category list in either HTML list or custom format.
	 *
	 * @param int $product_id Optional. Post ID to retrieve categories.
	 * @param string $before Optional. Before list.
	 * @param string $sep Optional. Separate items using this.
	 * @param string $after Optional. After list.
	 */
	 function dukapress_category_list($product_id = false, $before = '', $sep = ', ', $after = ''){
		$terms = get_the_term_list($product_id, 'duka_category', $before, $sep, $after);
		if ($terms)
			return $terms;
		else
			return __('Uncategorized', 'dp-lang');
	 }

endif;

if (!function_exists('dukapress_tag_list')) :
	/**
	 * Retrieve product's tag list in either HTML list or custom format.
	 *
	 * @param int $product_id Optional. Post ID to retrieve categories.
	 * @param string $before Optional. Before list.
	 * @param string $sep Optional. Separate items using this.
	 * @param string $after Optional. After list.
	 */
	function dukapress_tag_list($product_id = false, $before = '', $sep = ', ', $after = ''){
	 	$terms = get_the_term_list($product_id, 'duka_tag', $before, $sep, $after);
		if ($terms)
			return $terms;
		else
			return __('No Tags', 'dp-lang');
	}
endif;


if (!function_exists('dukapress_tag_cloud')) :
/**
 * Display product tag cloud.
 *
 * The text size is set by the 'smallest' and 'largest' arguments, which will
 * use the 'unit' argument value for the CSS text size unit. The 'format'
 * argument can be 'flat' (default), 'list', or 'array'. The flat value for the
 * 'format' argument will separate tags with spaces. The list value for the
 * 'format' argument will format the tags in a UL HTML list. The array value for
 * the 'format' argument will return in PHP array type format.
 *
 * The 'orderby' argument will accept 'name' or 'count' and defaults to 'name'.
 * The 'order' is the direction to sort, defaults to 'ASC' and can be 'DESC'.
 *
 * The 'number' argument is how many tags to return. By default, the limit will
 * be to return the top 45 tags in the tag cloud list.
 *
 * The 'topic_count_text_callback' argument is a function, which, given the count
 * of the posts	 with that tag, returns a text for the tooltip of the tag link.
 *
 * The 'exclude' and 'include' arguments are used for the {@link get_tags()}
 * function. Only one should be used, because only one will be used and the
 * other ignored, if they are both set.
 *
 * @param bool $echo Optional. Whether or not to echo.
 * @param array|string $args Optional. Override default arguments.
 */
function dukapress_tag_cloud($echo = true, $args = array()) {

		$args['echo'] = false;
		$args['taxonomy'] = 'duka_tag';

		$cloud = '<div id="dukapress_tag_cloud">' . wp_tag_cloud($args) . '</div>';

		$cloud = apply_filters('dukapress_tag_cloud', $cloud, $args);

		if ($echo)
				echo $cloud;
		else
				return $cloud;
}
endif;

if (!function_exists('dukapress_related_products')) :
/**
 * Displays related products for the passed product id
 *
 * @param int $product_id.
 * @param bool $in_same_category Optional, whether to limit related to the same category.
 * @param bool $echo. Optional, whether to echo or return the results
 * @param int $limit. Optional The number of products we want to retrieve.
 * @param bool $simple_list Optional, whether to show the related products based on the "list_view" setting or as a simple unordered list
 * @param bool $in_same_tags Optional, whether to limit related to same tags
 */
function dukapress_related_products() {
	global $dukapress, $post;

	$output = '';
	$categories = $tag_list = array();

	if( $dukapress->get_setting('related_products->show') == 0)
		return '';

	$defaults = array_merge($dukapress->defaults['related_products'], array(
		'simple_list' => $dukapress->get_setting('related_products->simple_list'),
		'relate_by' => $dukapress->get_setting('related_products->relate_by'),
		'limit' => $dukapress->get_setting('related_products->show_limit'),
	));

	$args = $dukapress->parse_args(func_get_args(), $defaults);

	if( !is_null($args['product_id']) ) {
		$args['product_id'] = ( isset($post) && $post->post_type == 'product' ) ? $post->ID : false;
		$product_details = get_post($args['product_id']);
	}else{
		$product_details = get_post($args['product_id']);
		$args['product_id'] = ( $product_details->post_type == 'product' ) ? $post->ID : false;
	}

	if( is_null($product_details) )
		return '';

	//setup the default args
	$query_args = array(
		'post_type' 	 => 'product',
		'posts_per_page' => intval($args['limit']),
		'post__not_in' 	 => array($args['product_id']),
		'tax_query' 	 => array(), //we'll add these later
	);

	//get the tags for this product
	if ( 'both' == $args['relate_by'] || 'tags' == $args['relate_by'] ) {
		$tags = get_the_terms( $args['product_id'], 'product_tag');

		if ( is_array($tags) ) {
			foreach($tags as $tag) {
				$tag_list[] = $tag->term_id;
			}

			//add the tag taxonomy query
			$query_args['tax_query'][] = array(
					'taxonomy' => 'product_tag',
					'field' => 'id',
					'terms' => $tag_list,
					'operator' => 'IN'
			);
		}
	}

	//are we limiting to only the assigned categories
	if( 'both' == $args['relate_by'] || 'category' == $args['relate_by'] ) {
		$product_cats = get_the_terms( $args['product_id'], 'product_category' );

		if( is_array($product_cats) ) {
			foreach($product_cats as $cat) {
				$categories[] = $cat->term_id;
			}

			$query_args['tax_query'][] = array(
					'taxonomy' => 'product_category',
					'field' => 'id',
					'terms' => $categories,
					'operator' => 'IN'
			);
		}
	}

	//we only want to run the query if we have categories or tags to look for.
	if ( count($tag_list) > 0 || count($categories) > 0 ) {
		//make the query
		$related_query = new WP_Query($query_args);

		//how are we formatting the output
		if( $args['simple_list'] ) {

			$output = '<div id="dpsc_related_products">';
			$output .= '<div class="dpsc_related_products_title"><h4>' . apply_filters( 'dpsc_related_products_title', __('Related Products','dp-lang') ) . '</h4></div>';
			if( $related_query->post_count ) {
				$list = '<ul class="dpsc_related_products_list">%s</ul>';
				$items = '';
				foreach($related_query->posts as $product) {
					$items .= '<li class="dpsc_related_products_list_item"><a href="'.get_permalink($product->ID).'">'.$product->post_title.'</a></li>';
				}
				$output .= sprintf($list, $items);
			}else{
				$output .= '<div class="dpsc_related_products_title"><h4>'. apply_filters( 'dpsc_related_products_title_none', __('No Related Products','dp-lang') ) . '</h4></div>';
			}

			$output .= '</div>';
		} else {
			//we'll use the $mp settings and functions
			$layout_type = $mp->get_setting('list_view');
			$output = '<div id="mp_related_products" class="mp_' . $layout_type . '">';
			//do we have posts?
			if( $related_query->post_count ) {
				$output .= '<div class="dpsc_related_products_title"><h4>' . apply_filters( 'dpsc_related_products_title', __('Related Products','dp-lang') ) . '</h4></div>';
                $output .= dukapress_products_view($related_query, 3, $layout_type);
			}else{
				$output .= '<div class="dpsc_related_products_title"><h4>'. apply_filters( 'dpsc_related_products_title_none', __('No Related Products','dp-lang') ) . '</h4></div>';
			}

			$output .= '</div>';
		}
	}

	$output = apply_filters('dukapress_related_products', $output, $args);

	//how are we sending back the data
	if($args['echo']) {
		echo $output;
	}else{
		return $output;
	}
}
endif;


if (!function_exists('dukapress_pinit_button')) :
/**
 * Pinterest PinIt button
 */
function dukapress_pinit_button( $product_id = NULL, $context = 'single_view', $echo = false ) {
	global $dukapress, $id;

	$post_id = ($product_id === NULL) ? $id : $product_id;
	$setting = $dukapress->get_setting('social->pinterest->show_pinit_button');

	if( $setting == 'off' || $setting != $context ) {
		return '';
	}

	$url = urlencode( get_permalink( $post_id ) );
	$desc = urlencode( get_the_title( $post_id ) );

	$image_info =	$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id($post_id), 'large');
	$media = ( $image_info ) ?	 '&media='.urlencode( $image_info[0] ) : '';

	$count_pos = ( $pos = $mp->get_setting('social->pinterest->show_pin_count') ) ? $pos : 'none';

	$snippet = apply_filters('mp_pinit_button_link', '
		<a href="//www.pinterest.com/pin/create/button/?url='.$url . $media .'&description='.$desc.'" data-pin-do="buttonPin" data-pin-config="'. $count_pos.'" target="_blank"><img src="//assets.pinterest.com/images/pidgets/pin_it_button.png" /></a>', $product_id, $context);

	if($echo) {
		echo $snippet;
	}else{
		return $snippet;
	}
}
endif;


if (!function_exists('dukapress_popular_products')) :
/**
 * Displays a list of popular products ordered by sales.
 *
 * @param bool $echo Optional, whether to echo or return
 * @param int $num Optional, max number of products to display. Defaults to 5
 */
function dukapress_popular_products($echo = true, $num = 5) {
		//The Query
		$custom_query = new WP_Query('post_type=duka&post_status=publish&posts_per_page=' . intval($num) . '&meta_key=duka_sales_count&meta_compare=>&meta_value=0&orderby=meta_value_num&order=DESC');

		$content = '<ul id="dukapress_popular_products">';

		if (count($custom_query->posts)) {
				foreach ($custom_query->posts as $post) {
						$content .= '<li><a href="' . get_permalink($post->ID) . '">' . $post->post_title . '</a></li>';
				}
		} else {
				$content .= '<li>' . __('No Products', 'dp-lang') . '</li>';
		}

		$content .= '</ul>';

		$content = apply_filters('dukapress_popular_products', $content, $num);

		if ($echo)
				echo $content;
		else
				return $content;
}
endif;


if (!function_exists('dukapress_cart_link')) :
/**
 * Echos the current shopping cart link. If global cart is on reflects global location
 * @param bool $echo Optional, whether to echo. Defaults to true
 * @param bool $url Optional, whether to return a link or url. Defaults to show link.
 * @param string $link_text Optional, text to show in link.
 */
function dukapress_cart_link($echo = true, $url = false, $link_text = '') {
    global $dukapress;
    $checkout_url = $dukapress->get_setting('page_urls->checkout_url');
    if(empty($checkout_url)){
      $checkout_url = @get_page_link($dukapress->get_setting('page_urls->checkout_id'));
    }
	$link = $checkout_url;

	if (!$url) {
		$text = ($link_text) ? $link_text : __('Check Out', 'dp-lang');
		$link = '<a href="' . $link . '" class="dpsc_cart_link">' . $text . '</a>';
	}

	$link = apply_filters('dukapress_cart_link', $link, $echo, $url, $link_text);

	if ($echo)
		echo $link;
	else
		return $link;
}
endif;


if (!function_exists('dukapress_checkout_step_url')) :
/**
 * Returns the current shopping cart link with checkout step.
 *
 * @param string $checkoutstep. Possible values: checkout-edit, shipping, checkout, confirm-checkout, confirmation
 */
function dukapress_checkout_step_url($checkout_step) {
		return apply_filters('dukapress_checkout_step_url', dukapress_cart_link(false, true) . trailingslashit($checkout_step), $checkout_step);
}
endif;


if (!function_exists('dukapress_page_url')) :

    /**
    * Echos the page url set up by the admin
    * @param bool $echo Required, whether to echo. Defaults to true
    * @param bool $name Required, type of url.
    */
    function dukapress_page_url($echo = true, $name = 'checkout'){
        global $dukapress;
        $page_url = "";
        switch ($name) {
		      case 'thankyou':
                $page_url = $dukapress->get_setting('page_urls->thankyou_url');
                if(empty($page_url)){
                  $page_url = @get_page_link($dukapress->get_setting('page_urls->thankyou_id'));
                }
                if($echo){
                  echo $page_url;
                }else{
                  return $page_url;
                }
                break;
            case 'order':
                $page_url = $dukapress->get_setting('page_urls->orderlog_url');
                if(empty($page_url)){
                  $page_url = @get_page_link($dukapress->get_setting('page_urls->orderlog_id'));
                }
                if($echo){
                  echo $page_url;
                }else{
                  return $page_url;
                }
                break;
                
            case 'terms':
                $page_url = $dukapress->get_setting('page_urls->terms_url');
                if(empty($page_url)){
                    $terms_url = $dukapress->get_setting('page_urls->terms_id');
                    if(!empty($terms_url)){
                        $page_url = @get_page_link($terms_url);
                    }
                }
                if($echo){
                  echo $page_url;
                }else{
                  return $page_url;
                }
                break;
		
		  case 'checkout':
                dukapress_cart_link($echo);
                break;
        default:
            # code...
            break;
        }
    }

endif;


if (!function_exists('dukapress_shop_currency_conversion_rate')) :

/**
 * Get the conversion rate
 *
 * @param string $gateway_currency. Currency symbol to be converted
 */
function dukapress_shop_currency_conversion_rate($gateway_currency){
    global $dukapress;
    $shop_currency = $dukapress->get_setting('shop_currency');
    $conversion_rate = 1;
    if($shop_currency != $gateway_currency){
        $conversion_rate = DP_CURRENCYCONVERTER::convert(1, $gateway_currency, $shop_currency);
    }
    return $conversion_rate;
}

endif;

if (!function_exists('dukapress_checkout_setting_value')) :

/**
 * Get the Value of an item in the custom Checkout settings
 *
 * @param $checkout_array - The array
 * @param $option_unique_name - the uname value
 *
 */
function dukapress_checkout_setting_value($checkout_array, $option_unique_name){
    $item_index =  array_search($option_unique_name, array_column($checkout_array, 'uname'));
    if($item_index !== FALSE ){
        return $checkout_array[$item_index]['value'];
    }else{
        return false;
    }
}
endif;

if (!function_exists('dukapress_trim_name')) :

/**
 * Trim name
 *
 * @param string $name. Name to be trimmed
 * @param integer $length. length to trim to
 */
function dukapress_trim_name($name, $length = 127) {
  while (strlen(urlencode($name)) > $length)
    $name = substr($name, 0, -1);

  return urlencode($name);
}

endif;


if (! function_exists('array_column')) :
    
    /**
     * Some PHP installations do not have this function sadly
     *
     */
    function array_column(array $input, $columnKey, $indexKey = null) {
        $array = array();
        foreach ($input as $value) {
            if ( ! isset($value[$columnKey])) {
                trigger_error("Key \"$columnKey\" does not exist in array");
                return false;
            }
            if (is_null($indexKey)) {
                $array[] = $value[$columnKey];
            }
            else {
                if ( ! isset($value[$indexKey])) {
                    trigger_error("Key \"$indexKey\" does not exist in array");
                    return false;
                }
                if ( ! is_scalar($value[$indexKey])) {
                    trigger_error("Key \"$indexKey\" does not contain scalar value");
                    return false;
                }
                $array[$value[$indexKey]] = $value[$columnKey];
            }
        }
        return $array;
    }
endif;


if (! function_exists('dpsc_variation_name')) :

    /**
     * Print the parent variation name by ID
     * @param Integer $id - The id of the variation
     * @param Boolean $echo - Echo the string or return the string
     */
    function dpsc_variation_name($id, $echo = false){
        $variation_name = $id;
        if(is_numeric($id)){
            $term = get_term( $id, 'duka_variation');
            if($term){
                $variation_name = $term->name;
            }
        }
        if($echo)
            echo $variation_name;
        else
            return $variation_name;
    }

endif;
?>
